@@ -53,10 +53,10 @@ class ADS1015(ADS1x15):
         """Rate configuration masks."""
         return _ADS1015_CONFIG_DR
 
-    def _data_rate_default(self):
+    def _data_rate_default(self) -> int:
         return 1600
 
-    def _conversion_value(self, raw_adc):
+    def _conversion_value(self, raw_adc: int) -> int:
         raw_adc = raw_adc.to_bytes(2, "big")
         value = struct.unpack(">h", raw_adc)[0]
         return value >> 4
