@@ -54,10 +54,10 @@ class ADS1115(ADS1x15):
         """Rate configuration masks."""
         return _ADS1115_CONFIG_DR
 
-    def _data_rate_default(self):
+    def _data_rate_default(self) -> int:
         return 128
 
-    def _conversion_value(self, raw_adc):
+    def _conversion_value(self, raw_adc: int) -> int:
         raw_adc = raw_adc.to_bytes(2, "big")
         value = struct.unpack(">h", raw_adc)[0]
         return value
